Struct futex_queue::Receiver [−][src]
pub struct Receiver<T, const N: usize> { /* fields omitted */ }Expand description
Receiver half of the queue.
Implementations
Tries to receive from the queue without blocking. Immediate items are returned first, then scheduled items in the order of earliest deadline first. Error contains an optional Instant of the earliest (not ready) deadline in the queue.