Struct futex_queue::Sender[][src]

pub struct Sender<T, const N: usize> { /* fields omitted */ }
Sender half of the queue. Safe to share between threads.

Implementations

Sends an item into the queue. The receive order of sent items is not guaranteed.

Puts item into a queue to be received at a specified instant. Receive order is earliest deadline first (after all immediate items).